@@ -44,8 +44,9 @@ from bokeh.models.callbacks import Callback
 
 from ...utils import serialize, deserialize
 from ..state import casalib_url, cubevisjs_url
+from .. import BokehInit
 
-class DataPipe(DataSource):
+class DataPipe(DataSource,BokehInit):
     """This class allows for communication between Python and the JavaScript implementation
     running in a browser. It allows Python code to send a message to JavaScript and register
     a callback which will receive the result. JavaScript code can do the same to request
@@ -75,7 +76,10 @@ class DataPipe(DataSource):
     _active_sessions = {}  # session_id -> {'websocket': ws, 'timestamp': time, 'datapipe': instance}
     _session_lock = threading.Lock()
 
-    __javascript__ = [ casalib_url( ), cubevisjs_url( ) ]
+    ###################################################################
+    ### filled from cubevis.bokeh.state._initialize._order_bokeh_js ###
+    ###################################################################
+    #__javascript__ = [ casalib_url( ), cubevisjs_url( ) ]
 
     def __init__( self, *args, abort=None, **kwargs ):
         super( ).__init__( *args, **kwargs )
